@@ -1,4 +1,6 @@
 package Devel::Optic::Lens::Perlish::Constants;
+use strict;
+use warnings;
 use Exporter qw(import);
 
 use constant {
@@ -46,7 +48,7 @@ Devel::Optic::Lens::Perlish::Constants
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 AUTHOR
 
